Milon |Build Status| |Coveralls| |Pypi| |Code Quality|
=====

A hebrew dictionary in python.

.. |Pypi| image:: https://badge.fury.io/py/python-milon.svg
   :target: https://badge.fury.io/py/python-milon
.. |Build Status| image:: https://travis-ci.org/alejandrogallo/python-milon.svg?branch=master
   :target: https://travis-ci.org/alejandrogallo/python-milon
.. |Coveralls| image:: https://coveralls.io/repos/github/alejandrogallo/python-milon/badge.svg?branch=master
   :target: https://coveralls.io/github/alejandrogallo/python-milon?branch=master
.. |Code Quality| image:: https://img.shields.io/lgtm/grade/python/g/alejandrogallo/python-milon.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/alejandrogallo/python-milon/context:python
